@@ -25,6 +25,9 @@ for those people who are interested.
 local pairs = pairs
 local print = print
 
+local lower = string.lower
+local match = string.match
+
 -- Copy files to the main CTAN release directory
 function copyctan()
   mkdir(ctandir .. "/" .. ctanpkg)
@@ -129,6 +132,17 @@ function ctan()
         cp(i, j, tdsdir .. "/doc/" .. tdsroot .. "/" .. bundle)
       end
     end
+    -- Rename README if necessary
+    if ctanreadme ~= "" and not match(lower(ctanreadme),"^readme%.%w+") then
+      local newfile = "README." .. match(ctanreadme,"%.(%w+)$")
+      for _,dir in pairs({ctandir .. "/" .. ctanpkg,
+        tdsdir .. "/doc/" .. tdsroot .. "/" .. bundle}) do
+        if fileexists(dir .. "/" .. ctanreadme) then
+          rm(dir,newfile)
+          ren(dir,ctanreadme,newfile)
+        end
+      end
+    end
     dirzip(tdsdir, ctanpkg .. ".tds")
     if packtdszip then
       cp(ctanpkg .. ".tds.zip", tdsdir, ctandir)
